Imports

Struct Imports 

pub struct Imports {
    pub functions: Vec<FuncImport>,
    pub tables: Vec<TableImport>,
    pub memories: Vec<MemoryImport>,
    pub globals: Vec<GlobalImport>,
}
All functions, tables, memories, and globals requested from the host environment.

They are required to be supplied for instantiation to succeed.

Fields

functions: Vec<FuncImport>tables: Vec<TableImport>memories: Vec<MemoryImport>globals: Vec<GlobalImport>

Implementations

Source

impl Imports

pub const fn empty() -> Self

The smallest set of imports: nothing.

pub fn len(&self) -> usize

The total number of imports

pub fn is_empty(&self) -> bool

Are there no imports?